@@ -2,7 +2,6 @@ from dataclasses import dataclass, field
 from datetime import datetime
 from enum import Enum
 from typing import Optional, List
-from uuid import UUID
 
 from shuttl_geo import Location
 from shuttlis.serialization import serialize
@@ -64,7 +63,7 @@ class Address:
 
 @dataclass
 class UserProfile:
-    user_id: UUID
+    user_id: str
     name: str
     gender: Gender
     home_address: Address
@@ -154,7 +153,7 @@ class UserProfile:
 
 @dataclass
 class UserDevice:
-    user_id: UUID
+    user_id: str
     device_id: str
     app_version: str = None
     platform: str = None
@@ -182,7 +181,7 @@ class UserDevice:
 
 @dataclass
 class Credential:
-    id: UUID
+    id: str
     type: CredentialType
     identity: str
     verified: bool
@@ -199,7 +198,7 @@ class Credential:
 
 @dataclass
 class User:
-    id: UUID
+    id: str
     identities: [Credential]
 
     @classmethod
