@@ -1,6 +1,5 @@
 from http import HTTPStatus
 from typing import List, Optional, Dict
-from uuid import UUID
 
 import requests
 
@@ -207,7 +206,7 @@ class UserService:
 
         self._raise_response_error(response)
 
-    def update_profile(self, user_id: UUID, profile: dict) -> UserProfile:
+    def update_profile(self, user_id: str, profile: dict) -> UserProfile:
         request_url = f"{self._profile_url}/api/v1/new/profiles/{user_id}"
         response = requests.patch(url=request_url, json=profile)
         log(
@@ -228,7 +227,7 @@ class UserService:
 
         self._raise_response_error(response)
 
-    def get_user_profile(self, id: UUID) -> UserProfile:
+    def get_user_profile(self, id: str) -> UserProfile:
         request_url = f"{self._profile_url}/api/v1/profiles/{id}"
         response = requests.get(request_url)
         log(
@@ -260,7 +259,7 @@ class UserService:
 
         self._raise_response_error(response)
 
-    def get_user_profiles(self, ids: List[UUID]) -> List[UserProfile]:
+    def get_user_profiles(self, ids: List[str]) -> List[UserProfile]:
         request_url = f"{self._profile_url}/api/v1/profiles/by_user_ids"
         response = requests.get(request_url, params={"ids": ",".join(map(str, ids))})
         log(
@@ -449,7 +448,7 @@ class UserService:
 
         self._raise_response_error(response)
 
-    def get_user(self, user_id: UUID) -> User:
+    def get_user(self, user_id: str) -> User:
         response = requests.get(f"{self._authentication_url}/api/v1/users/{user_id}")
         if response.status_code == HTTPStatus.OK:
             return User.from_dict(response.json()["data"])
